==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/util/DataEditorEvent.hpp <==
#ifndef _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HPP_
#define _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HDL_
#include "com/sun/star/util/DataEditorEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_UTIL_DATAEDITOREVENTTYPE_HPP_
#include "com/sun/star/util/DataEditorEventType.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace util {

inline DataEditorEvent::DataEditorEvent() SAL_THROW( () )
    : ::com::sun::star::lang::EventObject()
    , Type(::com::sun::star::util::DataEditorEventType_DONE)
{
}

inline DataEditorEvent::DataEditorEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::com::sun::star::util::DataEditorEventType& Type_) SAL_THROW( () )
    : ::com::sun::star::lang::EventObject(Source_)
    , Type(Type_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::util::DataEditorEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.util.DataEditorEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/util/DataEditorEvent.hpp <==
#ifndef _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HPP_
#define _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HDL_
#include "com/sun/star/util/DataEditorEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_UTIL_DATAEDITOREVENTTYPE_HPP_
#include "com/sun/star/util/DataEditorEventType.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace util {

inline DataEditorEvent::DataEditorEvent() SAL_THROW( () )
    : ::com::sun::star::lang::EventObject()
    , Type(::com::sun::star::util::DataEditorEventType_DONE)
{
}

inline DataEditorEvent::DataEditorEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::com::sun::star::util::DataEditorEventType& Type_) SAL_THROW( () )
    : ::com::sun::star::lang::EventObject(Source_)
    , Type(Type_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace util {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::util::DataEditorEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.util.DataEditorEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::util::DataEditorEvent const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::util::DataEditorEvent >::get();
}

#endif // _COM_SUN_STAR_UTIL_DATAEDITOREVENT_HPP_
